@@ -103,85 +103,92 @@ void LoadCategoriesJob::start()
     mCustomCategories.clear();
     mQtKdeCategories.clear();
     mFoundOverrideRule = false;
-
-    const QString envPath = mFileName;
-
-    if (!envPath.isEmpty()) {
-        const int number(mCategories.count());
-        QList<KDebugSettingsUtil::LoadLoggingCategory> qtCategories = KDebugSettingsUtil::readLoggingQtCategories(envPath);
-        for (int i = 0; i < number; ++i) {
-            KdeLoggingCategory kdeCat = mCategories.at(i);
-            bool foundInConfigFile = false;
-            Q_FOREACH (const KDebugSettingsUtil::LoadLoggingCategory &cat, qtCategories) {
-                if (cat.logName == kdeCat.logName) {
-
-                    LoggingCategory tmp;
-                    LoggingCategory::LoggingType newType = canDisplayType(cat.loggingTypes);
-                    if (newType != LoggingCategory::Undefined) {
-                        tmp.loggingType = canDisplayType(cat.loggingTypes);
-                        if (tmp.loggingType == LoggingCategory::Off) {
-                            tmp.enabled = false;
-                        }
-                        tmp.description = kdeCat.description;
-                        tmp.logName = kdeCat.logName;
-
-                        mQtKdeCategories.append(tmp);
-                        foundInConfigFile = true;
-                        qtCategories.removeAll(cat);
-                        break;
-                    }
-                }
-                if (cat.logName == QLatin1String("*")) {
-                    mFoundOverrideRule = true;
-                }
-            }
-            if (!foundInConfigFile) {
-                LoggingCategory tmp;
-                tmp.description = kdeCat.description;
-                tmp.logName = kdeCat.logName;
-                tmp.loggingType = LoggingCategory::Info;
-                mQtKdeCategories.append(tmp);
+    const int number(mCategories.count());
+    const QList<KDebugSettingsUtil::LoadLoggingCategory> originalQtCategories = KDebugSettingsUtil::readLoggingQtCategories(mFileName);
+    QList<KDebugSettingsUtil::LoadLoggingCategory> qtCategories;
+    Q_FOREACH (KDebugSettingsUtil::LoadLoggingCategory cat, originalQtCategories) {
+        Q_FOREACH(const RenameCategory &catRenamed, mRenameCategories) {
+            if (cat.logName == catRenamed.originalName) {
+                cat.logName = catRenamed.newName;
+                break;
             }
         }
+        qtCategories.append(cat);
+    }
 
-        //qDebug()<<" KEEP "<< qtCategories.count();
-        Q_FOREACH (const KDebugSettingsUtil::LoadLoggingCategory &cat, qtCategories) {
+    for (int i = 0; i < number; ++i) {
+        KdeLoggingCategory kdeCat = mCategories.at(i);
 
-            QMapIterator<KDebugSettingsUtil::LoadLoggingCategory::LogType, KDebugSettingsUtil::LoadLoggingCategory::Status> i(cat.loggingTypes);
-            while (i.hasNext()) {
-                i.next();
-                if (i.value() != KDebugSettingsUtil::LoadLoggingCategory::UnknownStatus) {
-                    LoggingCategory tmp;
-                    tmp.logName = cat.logName;
-                    switch (i.key()) {
-                    case KDebugSettingsUtil::LoadLoggingCategory::Unknown:
-                        tmp.loggingType = LoggingCategory::Undefined;
-                        break;
-                    case KDebugSettingsUtil::LoadLoggingCategory::Off:
-                        tmp.loggingType = LoggingCategory::Off;
+        bool foundInConfigFile = false;
+        Q_FOREACH (KDebugSettingsUtil::LoadLoggingCategory cat, qtCategories) {
+            if (cat.logName == kdeCat.logName) {
+
+                LoggingCategory tmp;
+                LoggingCategory::LoggingType newType = canDisplayType(cat.loggingTypes);
+                if (newType != LoggingCategory::Undefined) {
+                    tmp.loggingType = canDisplayType(cat.loggingTypes);
+                    if (tmp.loggingType == LoggingCategory::Off) {
                         tmp.enabled = false;
-                        break;
-                    case KDebugSettingsUtil::LoadLoggingCategory::Info:
-                        tmp.loggingType = LoggingCategory::Info;
-                        break;
-                    case KDebugSettingsUtil::LoadLoggingCategory::Warning:
-                        tmp.loggingType = LoggingCategory::Warning;
-                        break;
-                    case KDebugSettingsUtil::LoadLoggingCategory::Debug:
-                        tmp.loggingType = LoggingCategory::Debug;
-                        break;
-                    case KDebugSettingsUtil::LoadLoggingCategory::Critical:
-                        tmp.loggingType = LoggingCategory::Critical;
-                        break;
-                    case KDebugSettingsUtil::LoadLoggingCategory::All:
-                        tmp.loggingType = LoggingCategory::All;
-                        break;
                     }
-                    tmp.enabled = (i.value() == KDebugSettingsUtil::LoadLoggingCategory::Enabled);
-                    mCustomCategories.append(tmp);
+                    tmp.description = kdeCat.description;
+                    tmp.logName = kdeCat.logName;
 
+                    mQtKdeCategories.append(tmp);
+                    foundInConfigFile = true;
+                    qtCategories.removeAll(cat);
+                    break;
                 }
             }
+            if (cat.logName == QLatin1String("*")) {
+                mFoundOverrideRule = true;
+            }
+        }
+        if (!foundInConfigFile) {
+            LoggingCategory tmp;
+            tmp.description = kdeCat.description;
+            tmp.logName = kdeCat.logName;
+            tmp.loggingType = LoggingCategory::Info;
+            mQtKdeCategories.append(tmp);
+        }
+    }
+
+    //qDebug()<<" KEEP "<< qtCategories.count();
+    Q_FOREACH (const KDebugSettingsUtil::LoadLoggingCategory &cat, qtCategories) {
+
+        QMapIterator<KDebugSettingsUtil::LoadLoggingCategory::LogType, KDebugSettingsUtil::LoadLoggingCategory::Status> i(cat.loggingTypes);
+        while (i.hasNext()) {
+            i.next();
+            if (i.value() != KDebugSettingsUtil::LoadLoggingCategory::UnknownStatus) {
+                LoggingCategory tmp;
+                tmp.logName = cat.logName;
+                switch (i.key()) {
+                case KDebugSettingsUtil::LoadLoggingCategory::Unknown:
+                    tmp.loggingType = LoggingCategory::Undefined;
+                    break;
+                case KDebugSettingsUtil::LoadLoggingCategory::Off:
+                    tmp.loggingType = LoggingCategory::Off;
+                    tmp.enabled = false;
+                    break;
+                case KDebugSettingsUtil::LoadLoggingCategory::Info:
+                    tmp.loggingType = LoggingCategory::Info;
+                    break;
+                case KDebugSettingsUtil::LoadLoggingCategory::Warning:
+                    tmp.loggingType = LoggingCategory::Warning;
+                    break;
+                case KDebugSettingsUtil::LoadLoggingCategory::Debug:
+                    tmp.loggingType = LoggingCategory::Debug;
+                    break;
+                case KDebugSettingsUtil::LoadLoggingCategory::Critical:
+                    tmp.loggingType = LoggingCategory::Critical;
+                    break;
+                case KDebugSettingsUtil::LoadLoggingCategory::All:
+                    tmp.loggingType = LoggingCategory::All;
+                    break;
+                }
+                tmp.enabled = (i.value() == KDebugSettingsUtil::LoadLoggingCategory::Enabled);
+                mCustomCategories.append(tmp);
+
+            }
         }
     }
 }
@@ -191,6 +198,11 @@ void LoadCategoriesJob::setCategories(const KdeLoggingCategory::List &categories
     mCategories = categories;
 }
 
+void LoadCategoriesJob::setRenamedCategories(const RenameCategory::List &renameCategories)
+{
+    mRenameCategories = renameCategories;
+}
+
 LoggingCategory::List LoadCategoriesJob::customCategories() const
 {
     return mCustomCategories;
